Change namings to avoid non-inclusive one

Test: unit tests
Bug: 160331782
Change-Id: Ia0f5635ceb2f8081155aedc4fdf1bd949fa03201
diff --git a/global_configuration/com/android/tradefed/config/GlobalConfiguration.java b/global_configuration/com/android/tradefed/config/GlobalConfiguration.java
index 9d6c7a9..4e09a9b 100644
--- a/global_configuration/com/android/tradefed/config/GlobalConfiguration.java
+++ b/global_configuration/com/android/tradefed/config/GlobalConfiguration.java
@@ -94,7 +94,7 @@
 
     // Configurations to be passed to subprocess: Typical object that are representing the host
     // level and the subprocess should follow too.
-    private static final String[] CONFIGS_FOR_SUBPROCESS_WHITE_LIST =
+    private static final String[] CONFIGS_FOR_SUBPROCESS_ALLOW_LIST =
             new String[] {
                 DEVICE_MANAGER_TYPE_NAME,
                 KEY_STORE_TYPE_NAME,
@@ -777,13 +777,13 @@
 
     /** {@inheritDoc} */
     @Override
-    public File cloneConfigWithFilter(String... whitelistConfigs) throws IOException {
-        return cloneConfigWithFilter(new HashSet<>(), whitelistConfigs);
+    public File cloneConfigWithFilter(String... allowlistConfigs) throws IOException {
+        return cloneConfigWithFilter(new HashSet<>(), allowlistConfigs);
     }
 
     /** {@inheritDoc} */
     @Override
-    public File cloneConfigWithFilter(Set<String> exclusionPatterns, String... whitelistConfigs)
+    public File cloneConfigWithFilter(Set<String> exclusionPatterns, String... allowlistConfigs)
             throws IOException {
         IConfigurationFactory configFactory = getConfigurationFactory();
         IGlobalConfiguration copy = null;
@@ -799,10 +799,10 @@
         File filteredGlobalConfig = FileUtil.createTempFile("filtered_global_config", ".config");
         KXmlSerializer serializer = ConfigurationUtil.createSerializer(filteredGlobalConfig);
         serializer.startTag(null, ConfigurationUtil.CONFIGURATION_NAME);
-        if (whitelistConfigs == null || whitelistConfigs.length == 0) {
-            whitelistConfigs = CONFIGS_FOR_SUBPROCESS_WHITE_LIST;
+        if (allowlistConfigs == null || allowlistConfigs.length == 0) {
+            allowlistConfigs = CONFIGS_FOR_SUBPROCESS_ALLOW_LIST;
         }
-        for (String config : whitelistConfigs) {
+        for (String config : allowlistConfigs) {
             Object configObj = copy.getConfigurationObject(config);
             if (configObj == null) {
                 CLog.d("Object '%s' was not found in global config.", config);
diff --git a/global_configuration/com/android/tradefed/config/IGlobalConfiguration.java b/global_configuration/com/android/tradefed/config/IGlobalConfiguration.java
index 78096da..1107f5f 100644
--- a/global_configuration/com/android/tradefed/config/IGlobalConfiguration.java
+++ b/global_configuration/com/android/tradefed/config/IGlobalConfiguration.java
@@ -295,7 +295,7 @@
     public void validateOptions() throws ConfigurationException;
 
     /**
-     * Filter the GlobalConfiguration based on a white list and output to an XML file.
+     * Filter the GlobalConfiguration based on a allowed list and output to an XML file.
      *
      * <p>For example, for following configuration:
      * {@code
@@ -318,24 +318,24 @@
      * </xml>
      * }
      *
      * @param whitelistConfigs a {@link String} array of configs to be included in the new XML file.
      *     If it's set to <code>null<code/>, a default list should be used.
      * @return the File containing the new filtered global config.
      * @throws IOException
      */
-    public File cloneConfigWithFilter(String... whitelistConfigs) throws IOException;
+    public File cloneConfigWithFilter(String... allowlistConfigs) throws IOException;
 
     /**
      * Filter the GlobalConfiguration based on a white list and output to an XML file.
      * @see #cloneConfigWithFilter(String...)
      *
      * @param exclusionPatterns The pattern of class name to exclude from the dump.
      * @param whitelistConfigs a {@link String} array of configs to be included in the new XML file.
      *     If it's set to <code>null<code/>, a default list should be used.
      * @return the File containing the new filtered global config.
      * @throws IOException
      */
-    public File cloneConfigWithFilter(Set<String> exclusionPatterns, String... whitelistConfigs)
+    public File cloneConfigWithFilter(Set<String> exclusionPatterns, String... allowlistConfigs)
             throws IOException;
 
     /**
@@ -318,24 +318,24 @@
      * }
      *
-     * @param whitelistConfigs a {@link String} array of configs to be included in the new XML file.
+     * @param allowlistConfigs a {@link String} array of configs to be included in the new XML file.
      *     If it's set to <code>null<code/>, a default list should be used.
      * @return the File containing the new filtered global config.
@@ -318,24 +318,24 @@
      *
      * @param exclusionPatterns The pattern of class name to exclude from the dump.
-     * @param whitelistConfigs a {@link String} array of configs to be included in the new XML file.
+     * @param allowlistConfigs a {@link String} array of configs to be included in the new XML file.
      *     If it's set to <code>null<code/>, a default list should be used.
      * @return the File containing the new filtered global config.